# WooCommerce Developer Documentation

> ⚠️ **Notice:** This documentation is currently a **work in progress**. While it's open to the public for transparency and collaboration, please be aware that some sections might be incomplete or subject to change. We appreciate your patience and welcome any contributions!

This is your go-to place to find everything you need to know to get started with WooCommerce development, including implementation details for specific parts of the WooCommerce code base. 

## Getting started

WooCommerce is a customizable, open-source eCommerce platform built on WordPress. It empowers businesses worldwide to sell anything from physical products and digital downloads to subscriptions, content, and even appointments.

Get familiar with [WordPress Plugin Development](https://developer.wordpress.org/plugins/).

Take a moment to familiarize yourself with our [Developer Resources](https://developer.wordpress.org/plugins/plugin-basics/).

Once you're ready to move forward, consider one of the following:

- [Tools for low code development](getting-started/tools-for-low-code-development.md)
- [Building your first extension](extension-development/building-your-first-extension.md)
- [How to design a simple extension](extension-development/how-to-design-a-simple-extension.md)

## Contributions

The WooCommerce ecosystem thrives on community contributions. Whether it's improving documentation, reporting bugs, or contributing code, we greatly appreciate every contribution from our community. 

- To contribute to **the core WooCommerce project**, check out our [Contributing guide](https://github.com/woocommerce/woocommerce/blob/trunk/.github/CONTRIBUTING.md).
- To contribute to **documentation** please refer to the [documentation style guide](style-guide.md).

## Support

- To request a **new document, correction, or improvement**, [create an issue](https://github.com/woocommerce/woodocs/issues/new/choose).
- For development help, start with the [WooCommerce Community Forum](https://wordpress.org/support/plugin/woocommerce/), to see if someone else has already asked the same question. You can also pose your question in the `#developers` channel of our [Community Slack](https://woocommerce.com/community-slack/). If you're not sure where to ask your question, you can always [contact us](https://woocommerce.com/contact-us/), and our Happiness Engineers will be glad to point you in the right direction.
- For additional support with customizations, you might consider hiring from [WooExperts](https://woocommerce.com/experts/) or [Codeable](https://codeable.io/).

### Additional Resources

- [WooCommerce Official Website](https://woocommerce.com/)
- [Woo Marketplace](https://woocommerce.com/marketplace)
- All [WooCommerce Repositories on GitHub](https://woocommerce.github.io/)

### Other documentation

Some directories contain documentation about their own contents, in the form of README file. The available files are listed below, **if you create a new README file please add it to the corresponding list.**

Available READMe files for the WooCommerce plugin: 

- [`Root README`](../plugins/woocommerce/README.md)
- [`i18n/languages`](../plugins/woocommerce/i18n/languages/README.md)
- [`includes`](../plugins/woocommerce/includes/README.md)
- [`lib`](../plugins/woocommerce/lib/README.md)
- [`packages`](../plugins/woocommerce/packages/README.md)
- [`src`](../plugins/woocommerce/src/README.md)
- [`src/Admin/RemoteInboxNotifications`](../plugins/woocommerce/src/Admin/RemoteInboxNotifications/README.md)
- [`src/Admin/RemoteInboxNotifications/Transformers`](../plugins/woocommerce/src/Admin/RemoteInboxNotifications/Transformers/README.md)
- [`src/Blocks`](../plugins/woocommerce/src/Blocks/README.md)
- [`src/Internal`](../plugins/woocommerce/src/Internal/README.md)
- [`src/Internal/Admin/ProductForm`](../plugins/woocommerce/src/Internal/Admin/ProductForm/README.md)
- [`tests`](../plugins/woocommerce/tests/README.md)
- [`tests/api-core-tests`](../plugins/woocommerce/tests/api-core-tests/README.md)
- [`tests/e2e`](../plugins/woocommerce/tests/e2e/README.md)
- [`tests/e2e-pw`](../plugins/woocommerce/tests/e2e-pw/README.md)
- [`tests/performance`](../plugins/woocommerce/tests/performance/README.md)
- [`tests/Tools/CodeHacking`](../plugins/woocommerce/tests/Tools/CodeHacking/README.md)

Available READMe files for the WooCommerce Admin plugin:

- [`Root README`](../plugins/woocommerce-admin/README.md)
- [`client/activity-panel`](../plugins/woocommerce-admin/client/activity-panel/README.md)
- [`client/activity-panel/activity-card`](../plugins/woocommerce-admin/client/activity-panel/activity-card/README.md)
- [`client/activity-panel/activity-header`](../plugins/woocommerce-admin/client/activity-panel/activity-header/README.md)
- [`client/analytics/report`](../plugins/woocommerce-admin/client/analytics/report/README.md)
- [`client/analytics/settings`](../plugins/woocommerce-admin/client/analytics/settings/README.md)
- [`client/dashboard`](../plugins/woocommerce-admin/client/dashboard/README.md)
- [`client/header`](../plugins/woocommerce-admin/client/header/README.md)
- [`client/marketing`](../plugins/woocommerce-admin/client/marketing/README.md)
- [`client/marketing/components/button`](../plugins/woocommerce-admin/client/marketing/components/button/README.md)
- [`client/marketing/components/card`](../plugins/woocommerce-admin/client/marketing/components/card/README.md)
- [`client/marketing/components/product-icon`](../plugins/woocommerce-admin/client/marketing/components/product-icon/README.md)
- [`client/utils`](../plugins/woocommerce-admin/client/utils/README.md)
- [`client/wp-admin-scripts`](../plugins/woocommerce-admin/client/wp-admin-scripts/README.md)
- [`docs`](../plugins/woocommerce-admin/docs/README.md)
- [`docs/examples`](../plugins/woocommerce-admin/docs/examples/README.md)
- [`docs/examples/extensions`](../plugins/woocommerce-admin/docs/examples/extensions/README.md)
- [`docs/features`](../plugins/woocommerce-admin/docs/features/README.md)
- [`docs/woocommerce.com`](../plugins/woocommerce-admin/docs/woocommerce.com/README.md)

Available READMe files for the WooCommerce Beta Tested plugin:

- [`Root README`](../plugins/woocommerce-beta-tester/README.md)
- [`src/tools`](../plugins/woocommerce-beta-tester/src/tools/README.md)
- [`userscripts`](../plugins/woocommerce-beta-tester/userscripts/README.md)
