# WooCommerce Developer Resources

This guide is a great starting point for WooCommerce development. From setting up your first online store to diving deep into advanced features, you'll find what you need here. New to WooCommerce? Start with the basics. Experienced and looking for specific documentation or community discussions? We've got that covered too. Navigate through the sections below to find the resources tailored for you.

## Getting Started

There are a few different ways you might want to get started utilizing WooCommerce. Choose a path below to start developing based on your code comfort level!

### [Installing and setting up WooCommerce](https://woocommerce.com/document/build-online-store/)

If you’re brand new to Woo, this guide will show you How to build an online store on WooCommerce. This is where you can learn the ins and outs of how WooCommerce works before you start developing.

### [Extension Development Quick Start](https://github.com/woocommerce/woocommerce/tree/trunk/packages/js/create-woo-extension)

This no-configuration quick-start package will scaffold a local copy of an extension template for you. Just open up your terminal and follow the steps in GitHub. 

### [Building your first extension](/extension-development/building-your-first-extension.md)

This guide will have you building your first extension with best practices and helpful tips.

### [Marketplace Contribution Guidelines](https://woocommerce.com/document/marketplace-overview/)

Are you hoping to sell your extension in the [Woo Marketplace](https://woocommerce.com/marketplace/)? Read our guidelines to make sure your extension is marketplace-ready.

### [Contributor Guidelines](https://github.com/woocommerce/woocommerce/blob/trunk/.github/CONTRIBUTING.md)

If you've ever wanted to contribute to the WooCommerce platform as a developer please read our guidelines for contribution first.

### [Contribution Environment Set-Up](https://github.com/woocommerce/woocommerce/tree/trunk)

Visit the WooCommerce home repository on GitHub to learn the first steps to environment set up and platform contribution expectations.

### [Developer tools](docs/getting-started/developer-tools.md)

Check out our guide to learn more about developer tools, libraries, and utilities. 

---


## API & Reference Docs

The resources below contain low-level documentation about features, libraries, extensions, and other pieces of WooCommerce architecture. Use them as a reference when building extensions or integrating with WooCommerce.

## [REST API](https://woocommerce.github.io/woocommerce-rest-api-docs/)

The WooCommerce REST API lets you create, read, update, and delete WooCommerce data using HTTP requests, so you can integrate external applications with WooCommerce and build extensions that make use of asynchronous UI frameworks such as React.

### [Core API](https://docs.woocommerce.com/wc-apidocs/index.html)

The WooCommerce Core API code reference contains information about packages and classes that make up WooCommerce's core functionality.

### [Store API](https://github.com/woocommerce/woocommerce-blocks/tree/trunk/src/StoreApi)

The Store API provides public Rest API endpoints for the development of customer-facing cart, checkout, and product functionality. It follows many of the patterns used in the [WordPress REST API](https://developer.wordpress.org/rest-api/key-concepts/).

### [WooCommerce Blocks](https://github.com/woocommerce/woocommerce-gutenberg-products-block/#documentation)

WooCommerce Blocks give you the ability to integrate WooCommerce with Gutenberg. Use the documentation and resources here as a starting point for developing new block types for WooCommerce.

### [Core Action and Filter Hooks](https://docs.woocommerce.com/wc-apidocs/hooks/hooks.html)

This contains an index of hooks found across all template files, functions, shortcodes, widgets, data stores, and core classes. You can use these hooks to extend the core WooCommerce platform by introducing custom behavior or modifying data that WooCommerce passes around.

### [Shortcodes Included with WooCommerce](https://docs.woocommerce.com/document/woocommerce-shortcodes/)

While WooCommerce Blocks are now the easiest and most flexible way to display your products on posts and pages, WooCommerce still comes with several shortcodes to insert content.

---

## GitHub Repositories

### [WooCommerce on GitHub](https://github.com/woocommerce)

This is the official WooCommerce organization on GitHub. Here you’ll find the majority of development work that happens on open source projects that the WooCommerce team maintains.

### [Automattic on GitHub](https://github.com/automattic)

This is the official Automattic organization on GitHub. It is where you'll find the majority of development work that happens on open source projects that the Automattic team maintains.

### [WordPress on GitHub](https://github.com/wordpress)

This is the official WordPress organization on GitHub –– a go-to source for the development work that happens on open source projects that the WordPress community maintains.

---

## Ecosystem Resources

### [WordPress Developer Resources](https://developer.wordpress.org/)

All the resources you need for developing with WordPress. If you’re not familiar with the WordPress development ecosystem, this is a great place to start.

### [WooCommerce Community Slack](https://woocommerce.com/community-slack)

Join our community on Slack. We hold regular sessions where we share information and field questions, but you can also connect with other developers to share challenges and ask questions.

### [WooCommerce Community Forum](https://wordpress.org/support/plugin/woocommerce/)

Use this forum to ask questions about WooCommerce. Our WooCommerce Happiness Engineers frequent this forum to answer questions, but there is also a wealth of knowledge that has been captured in these threads over the years.

### [WooCommerce on Reddit](https://www.reddit.com/r/woocommerce/)

Visit the WooCommerce subreddit to ask questions and share tips with other developers.
